@@ -43,7 +43,7 @@ orbit_idl_attr_fake_ops(IDL_tree attr, IDL_ns ns)
 
     attr_name = IDL_LIST(curnode).data;
 
-    g_string_sprintf(attrname, "_get_%s",
+    g_string_printf(attrname, "_get_%s",
 		     IDL_IDENT(attr_name).str);
     ident = IDL_ident_new(g_strdup(attrname->str));
     IDL_IDENT_TO_NS(ident) = IDL_IDENT_TO_NS(attr_name);
@@ -54,7 +54,7 @@ orbit_idl_attr_fake_ops(IDL_tree attr, IDL_ns ns)
     IDL_ns_place_new(ns, ident);
 
     if(!IDL_ATTR_DCL(attr).f_readonly) {
-      g_string_sprintf(attrname, "_set_%s",
+      g_string_printf(attrname, "_set_%s",
 		       IDL_IDENT(attr_name).str);
       ident = IDL_ident_new(g_strdup(attrname->str));
       IDL_IDENT_TO_NS(ident) = IDL_IDENT_TO_NS(attr_name);
@@ -127,14 +127,6 @@ orbit_idl_print_node(IDL_tree node, int indent_level)
     break;
 
   case IDLN_GENTREE:
-    g_print("GENTREE:\n");
-#if 0
-    /* Changed in libIDL.  But don't need it here anyway. */
-    orbit_idl_print_node(IDL_GENTREE(node).data, indent_level + INDENT_INCREMENT_1);
-    do_indent(indent_level + INDENT_INCREMENT_1);
-    g_print("children:\n");
-    orbit_idl_print_node(IDL_GENTREE(node).children, indent_level + INDENT_INCREMENT_2);
-#endif
     break;
 
   case IDLN_INTEGER:
@@ -379,288 +371,6 @@ orbit_idl_print_node(IDL_tree node, int indent_level)
   }
 }
 
-void
-oidl_marshal_tree_dump(IDL_tree tree, int indent_level)
-{
-  IDL_tree node;
-
-  if(!tree) return;
-
-  switch(IDL_NODE_TYPE(tree)) {
-  case IDLN_LIST:
-    for(node = tree; node; node = IDL_LIST(node).next) {
-      oidl_marshal_tree_dump(IDL_LIST(node).data, indent_level);
-    }
-    break;
-  case IDLN_MODULE:
-    do_indent(indent_level);
-    g_print("Module %s:\n", IDL_IDENT(IDL_MODULE(tree).ident).str);
-    oidl_marshal_tree_dump(IDL_MODULE(tree).definition_list, indent_level + INDENT_INCREMENT_2);
-    break;
-  case IDLN_INTERFACE:
-    do_indent(indent_level);
-    g_print("Interface %s:\n", IDL_IDENT(IDL_INTERFACE(tree).ident).str);
-    oidl_marshal_tree_dump(IDL_INTERFACE(tree).body, indent_level + INDENT_INCREMENT_2);
-    break;
-  case IDLN_OP_DCL:
-    do_indent(indent_level);
-    g_print("Operation %s:\n", IDL_IDENT(IDL_OP_DCL(tree).ident).str);
-#if 0
-    oidl_marshal_node_dump(((OIDL_Op_Info *)tree->data)->in_stubs, indent_level + INDENT_INCREMENT_2);
-    oidl_marshal_node_dump(((OIDL_Op_Info *)tree->data)->out_stubs, indent_level + INDENT_INCREMENT_2);
-#else
-    oidl_marshal_node_dump(((OIDL_Op_Info *)tree->data)->in_skels, indent_level + INDENT_INCREMENT_2);
-    oidl_marshal_node_dump(((OIDL_Op_Info *)tree->data)->out_skels, indent_level + INDENT_INCREMENT_2);
-#endif
-    break;
-  case IDLN_ATTR_DCL:
-    {
-      IDL_tree curnode, attr_name;
-
-      for(curnode = IDL_ATTR_DCL(tree).simple_declarations; curnode; curnode = IDL_LIST(curnode).next) {
-	attr_name = IDL_LIST(curnode).data;
-
-	oidl_marshal_tree_dump(((OIDL_Attr_Info *)attr_name->data)->op1, indent_level + INDENT_INCREMENT_2);
-	if(((OIDL_Attr_Info *)attr_name->data)->op2)
-	  oidl_marshal_tree_dump(((OIDL_Attr_Info *)attr_name->data)->op2, indent_level + INDENT_INCREMENT_2);
-      }
-    }
-    break;
-  default:
-    break;
-  }
-}
-
-void
-oidl_marshal_node_dump(OIDL_Marshal_Node *tree, int indent_level)
-{
-  char *ctmp;
-
-  do_indent(indent_level);
-
-  if(!tree) { g_print("Nil\n"); return; }
-
-  if(tree->use_count)
-    {
-      g_print("Recursive loopback to %p\n", tree);
-      return;
-    }
-
-  tree->use_count++;
-
-  ctmp = oidl_marshal_node_fqn(tree);
-  if(tree->name)
-    g_print("\"%s\" (\"%s\") ", tree->name, ctmp);
-  else
-    g_print("(\"%s\") ", ctmp);
-  g_free(ctmp);
-
-  g_print("(%s %p): [", nodenames[tree->type], tree);
-  if(tree->flags & MN_INOUT)
-    g_print("INOUT ");
-  if(tree->flags & MN_NSROOT)
-    g_print("NSROOT ");
-  if(tree->flags & MN_NEED_TMPVAR)
-    g_print("NEED_TMPVAR ");
-  if(tree->flags & MN_NOMARSHAL)
-    g_print("NOMARSHAL ");
-  if(tree->flags & MN_ISSEQ)
-    g_print("ISSEQ ");
-  if(tree->flags & MN_ISSTRING)
-    g_print("ISSTRING ");
-  if(tree->flags & MN_LOOPED)
-    g_print("LOOPED ");
-  if(tree->flags & MN_COALESCABLE)
-    g_print("COALESCABLE ");
-  if(tree->flags & MN_ENDIAN_DEPENDANT)
-    g_print("ENDIAN_DEPENDANT ");
-  if(tree->flags & MN_DEMARSHAL_UPDATE_AFTER)
-    g_print("DEMARSHAL_UPDATE_AFTER ");
-  if(tree->flags & MN_RECURSIVE_TOP)
-    g_print("RECURSIVE_TOP ");
-  if(tree->flags & MN_TOPLEVEL)
-    g_print("TOPLEVEL ");
-  if(tree->flags & MN_PARAM_INOUT)
-    g_print("PARAM_INOUT ");
-  if(tree->flags & MN_NEED_CURPTR_LOCAL)
-    g_print("NEED_CURPTR_LOCAL ");
-  if(tree->flags & MN_NEED_CURPTR_RECVBUF)
-    g_print("NEED_CURPTR_RECVBUF ");
-  g_print("] ");
-
-  if(tree->pre)
-    g_print("pre-check %d+%s*%s ", tree->pre->len, tree->pre->mult_const,
-	    tree->pre->mult_expr?tree->pre->mult_expr->name:"(null)");
-  if(tree->post)
-    g_print("post-check %d+%s*%s ", tree->post->len, tree->post->mult_const,
-	    tree->post->mult_expr?tree->post->mult_expr->name:"(null)");
-
-  g_print("*%d arch (%d,%d) iiop (%d,%d)\n", tree->nptrs,
-	  tree->arch_head_align, tree->arch_tail_align, tree->iiop_head_align, tree->iiop_tail_align);
-
-  switch(tree->type) {
-  case MARSHAL_LOOP:
-    do_indent(indent_level + INDENT_INCREMENT_1);
-    g_print("loop_var:\n");
-    oidl_marshal_node_dump(tree->u.loop_info.loop_var, indent_level + INDENT_INCREMENT_2);
-    do_indent(indent_level + INDENT_INCREMENT_1);
-    g_print("length_var:\n");
-    oidl_marshal_node_dump(tree->u.loop_info.length_var, indent_level + INDENT_INCREMENT_2);
-    do_indent(indent_level + INDENT_INCREMENT_1);
-    g_print("contents:\n");
-    oidl_marshal_node_dump(tree->u.loop_info.contents, indent_level + INDENT_INCREMENT_2);
-    break;
-  case MARSHAL_DATUM:
-    do_indent(indent_level + INDENT_INCREMENT_1);
-    g_print("datum_size: %d\n", tree->u.datum_info.datum_size);
-    break;
-  case MARSHAL_SET:
-    {
-      GSList *ltmp;
-      do_indent(indent_level + INDENT_INCREMENT_1);
-      g_print("subnodes:\n");
-      for(ltmp = tree->u.set_info.subnodes; ltmp; ltmp = g_slist_next(ltmp)) {
-	oidl_marshal_node_dump(ltmp->data, indent_level + INDENT_INCREMENT_2);
-	g_print("\n");
-      }
-    }
-    break;
-  case MARSHAL_SWITCH:
-    {
-      GSList *ltmp;
-
-      do_indent(indent_level + INDENT_INCREMENT_1);
-      g_print("discrim:\n");
-      oidl_marshal_node_dump(tree->u.switch_info.discrim, indent_level + INDENT_INCREMENT_2);
-      do_indent(indent_level + INDENT_INCREMENT_1);
-      g_print("cases:\n");
-      for(ltmp = tree->u.switch_info.cases; ltmp; ltmp = g_slist_next(ltmp)) {
-	oidl_marshal_node_dump(ltmp->data, indent_level + INDENT_INCREMENT_2);
-	g_print("\n");
-      }
-    }
-    break;
-  case MARSHAL_CASE:
-    {
-      GSList *ltmp;
-
-      do_indent(indent_level + INDENT_INCREMENT_1);
-      g_print("labels:\n");
-      for(ltmp = tree->u.case_info.labels; ltmp; ltmp = g_slist_next(ltmp)) {
-	oidl_marshal_node_dump(ltmp->data, indent_level + INDENT_INCREMENT_2);
-	g_print("\n");
-      }
-      g_print("contents:\n");
-      oidl_marshal_node_dump(tree->u.case_info.contents, indent_level + INDENT_INCREMENT_2);
-    }
-    break;
-  case MARSHAL_COMPLEX:
-    break;
-  case MARSHAL_CONST:
-    do_indent(indent_level + INDENT_INCREMENT_1);
-    g_print("amount: %ld\n", tree->u.const_info.amount);
-    break;
-  default:
-    g_warning("Don't know any details about %s nodes", nodenames[tree->type]);
-    break;
-  }
-
-  tree->use_count--;
-} 
-
-IDL_tree
-orbit_idl_get_array_type(IDL_tree tree)
-{
-  IDL_tree parent;
-
-  parent = IDL_get_parent_node(tree, IDLN_ANY, NULL);
-  g_assert(IDL_NODE_TYPE(parent) == IDLN_LIST);
-
-  parent = IDL_get_parent_node(parent, IDLN_ANY, NULL);
-  switch(IDL_NODE_TYPE(parent)) {
-  case IDLN_MEMBER:
-    return IDL_MEMBER(parent).type_spec;
-    break;
-  case IDLN_TYPE_DCL:
-    return IDL_TYPE_DCL(parent).type_spec;
-    break;
-  default:
-    g_assert(IDL_NODE_TYPE(parent) == IDLN_MEMBER
-	       || IDL_NODE_TYPE(parent) == IDLN_TYPE_DCL);
-  }
-
-  return NULL;
-}
-
-char *
-orbit_idl_member_get_name(IDL_tree tree)
-{
-  switch(IDL_NODE_TYPE(tree)) {
-  case IDLN_TYPE_ARRAY:
-    return orbit_idl_member_get_name(IDL_TYPE_ARRAY(tree).ident);
-    break;
-  case IDLN_IDENT:
-    return IDL_IDENT(tree).str;
-    break;
-  default:
-    g_error("Don't know how to get member name of a %s", IDL_tree_type_names[IDL_NODE_TYPE(tree)]);
-  }
-
-  return NULL;
-}
-
-void
-orbit_idl_node_foreach(OIDL_Marshal_Node *node, GFunc func, gpointer user_data)
-{
-  if(!node) return;
-
-  if(node->use_count)
-    return;
-
-  node->use_count++;
-
-  func(node, user_data);
-
-  switch(node->type) {
-  case MARSHAL_LOOP:
-    orbit_idl_node_foreach(node->u.loop_info.loop_var, func, user_data);
-    orbit_idl_node_foreach(node->u.loop_info.length_var, func, user_data);
-    orbit_idl_node_foreach(node->u.loop_info.contents, func, user_data);
-    break;
-  case MARSHAL_SWITCH:
-    {
-      GSList *ltmp;
-
-      orbit_idl_node_foreach(node->u.switch_info.discrim, func, user_data);
-
-      for(ltmp = node->u.switch_info.cases; ltmp; ltmp = g_slist_next(ltmp))
-	orbit_idl_node_foreach((OIDL_Marshal_Node *)ltmp->data, func, user_data);
-    }
-    break;
-  case MARSHAL_CASE:
-    {
-      GSList *ltmp;
-
-      for(ltmp = node->u.case_info.labels; ltmp; ltmp = g_slist_next(ltmp))
-	orbit_idl_node_foreach((OIDL_Marshal_Node *)ltmp->data, func, user_data);
-
-      orbit_idl_node_foreach(node->u.case_info.contents, func, user_data);
-    }
-    break;
-  case MARSHAL_SET:
-    {
-      GSList *ltmp;
-
-      for(ltmp = node->u.set_info.subnodes; ltmp; ltmp = g_slist_next(ltmp))
-	orbit_idl_node_foreach((OIDL_Marshal_Node *)ltmp->data, func, user_data);
-    }
-    break;
-  default:
-    break;
-  }
-  node->use_count--;
-}
-
 static void
 IDL_tree_traverse_helper(IDL_tree p, GFunc f,
 			 gconstpointer func_data,
@@ -830,13 +540,6 @@ oidl_param_info(IDL_tree param, IDL_ParamRole role, gboolean *isSlice)
   return retval;
 }
 
-gint
-oidl_param_numptrs(IDL_tree param, IDL_ParamRole role)
-{
-    gboolean isSlice;
-    return oidl_param_info(param, role, &isSlice);
-}
-
 /**
     Fixed-length-ness is a property that CORBA defines, and it is
     a property of each type, not each kind.  Furthermore, it doesnt
@@ -916,80 +619,6 @@ orbit_cbe_type_is_fixed_length(IDL_tree ts)
   }
 }
 
-#if 0
-/**
-    I have no idea what is meant by "complex" here. CORBA/GIOP defines
-    a type as being "empty", "simple" or "complex", and basically
-    describes how much info the TC has. But in that definition,
-    a sequnce is always complex, regardless of what it is a sequence of.
-    We need to research the caller's of this func, and see what
-    they really mean.
-**/
-gboolean
-orbit_cbe_type_contains_complex(IDL_tree ts)
-{
-  gboolean has_complex = FALSE;
-  IDL_tree curitem;
-
-  ts = orbit_cbe_get_typespec(ts);
-
-  switch(IDL_NODE_TYPE(ts)) {
-  case IDLN_TYPE_FLOAT:
-  case IDLN_TYPE_INTEGER:
-  case IDLN_TYPE_ENUM:
-  case IDLN_TYPE_CHAR:
-  case IDLN_TYPE_WIDE_CHAR:
-  case IDLN_TYPE_OCTET:
-  case IDLN_TYPE_BOOLEAN:
-  case IDLN_TYPE_STRING:
-  case IDLN_TYPE_WIDE_STRING:
-    return FALSE;
-    break;
-  case IDLN_TYPE_SEQUENCE:
-    return orbit_cbe_type_contains_complex(IDL_TYPE_SEQUENCE(ts).simple_type_spec);
-    break;
-  case IDLN_TYPE_OBJECT:
-  case IDLN_FORWARD_DCL:
-  case IDLN_INTERFACE:
-  case IDLN_TYPE_ANY:
-  case IDLN_TYPE_TYPECODE:
-    return TRUE;
-    break;
-  case IDLN_TYPE_UNION:
-    for(curitem = IDL_TYPE_UNION(ts).switch_body; curitem;
-	curitem = IDL_LIST(curitem).next) {
-      has_complex |= orbit_cbe_type_contains_complex(IDL_LIST(IDL_CASE_STMT(IDL_LIST(curitem).data).element_spec).data);
-    }
-    return has_complex;
-    break;
-  case IDLN_EXCEPT_DCL:
-  case IDLN_TYPE_STRUCT:
-    for(curitem = IDL_TYPE_STRUCT(ts).member_list; curitem;
-	curitem = IDL_LIST(curitem).next) {
-      has_complex |= orbit_cbe_type_contains_complex(IDL_LIST(curitem).data);
-    }
-    return has_complex;
-    break;
-  case IDLN_TYPE_ARRAY:
-    return orbit_cbe_type_contains_complex(IDL_TYPE_DCL(IDL_get_parent_node(ts, IDLN_TYPE_DCL, NULL)).type_spec);
-    break;
-  case IDLN_TYPE_DCL:
-    return orbit_cbe_type_contains_complex(IDL_TYPE_DCL(ts).type_spec);
-    break;
-  case IDLN_IDENT:
-  case IDLN_LIST:
-    return orbit_cbe_type_contains_complex(IDL_NODE_UP(ts));
-    break;
-  case IDLN_MEMBER:
-    return orbit_cbe_type_contains_complex(IDL_MEMBER(ts).type_spec);
-    break;
-  default:
-    g_warning("I'm not sure if type %s has a complex...", IDL_tree_type_names[IDL_NODE_TYPE(ts)]);
-    return FALSE;
-  }
-}
-#endif
-
 IDL_tree
 orbit_cbe_get_typespec(IDL_tree node)
 {
@@ -1054,13 +683,3 @@ oidl_attr_to_paramrole(enum IDL_param_attr attr)
     return -1;
   }
 }
-
-gboolean
-oidl_tree_is_pidl(IDL_tree tree) {
-    IDL_tree pnt;
-    for ( pnt=tree; pnt; pnt=IDL_NODE_UP(pnt) ) {
-	if ( pnt->declspec & IDLF_DECLSPEC_PIDL )
-	    return TRUE;
-    }
-    return FALSE;
-}
