@@ -524,7 +524,7 @@ CORBA_ORB_resolve_initial_references (CORBA_ORB          orb,
 }
 
 static CORBA_TypeCode
-CORBA_TypeCode_allocate (void)
+ORBit_TypeCode_allocate (void)
 {
 	CORBA_TypeCode tc = g_new0 (struct CORBA_TypeCode_struct, 1);
 
@@ -543,7 +543,7 @@ CORBA_ORB_create_struct_tc (CORBA_ORB                    orb,
 	CORBA_TypeCode retval;
 	int            i;
 
-	retval = CORBA_TypeCode_allocate ();
+	retval = ORBit_TypeCode_allocate ();
 	if (!retval)
 		goto tc_alloc_failed;
 
@@ -626,7 +626,7 @@ CORBA_ORB_create_union_tc (CORBA_ORB                   orb,
 	CORBA_TypeCode retval;
 	int            i;
 
-	retval = CORBA_TypeCode_allocate ();
+	retval = ORBit_TypeCode_allocate ();
 
 	if (!retval)
 		goto tc_alloc_failed;
@@ -695,7 +695,7 @@ CORBA_ORB_create_enum_tc (CORBA_ORB                  orb,
 	CORBA_TypeCode retval;
 	int            i;
 
-	retval = CORBA_TypeCode_allocate ();
+	retval = ORBit_TypeCode_allocate ();
 	if (!retval)
 		goto tc_alloc_failed;
 
@@ -733,7 +733,7 @@ CORBA_ORB_create_alias_tc (CORBA_ORB             orb,
 {
 	CORBA_TypeCode retval;
 
-	retval = CORBA_TypeCode_allocate ();
+	retval = ORBit_TypeCode_allocate ();
 	if (!retval)
 		goto tc_alloc_failed;
 	
@@ -771,7 +771,7 @@ CORBA_ORB_create_exception_tc (CORBA_ORB                    orb,
 	CORBA_TypeCode retval;
 	int            i;
 
-	retval = CORBA_TypeCode_allocate ();
+	retval = ORBit_TypeCode_allocate ();
 	if (!retval)
 		goto tc_alloc_failed;
 
@@ -823,7 +823,7 @@ CORBA_ORB_create_interface_tc (CORBA_ORB                 orb,
 {
 	CORBA_TypeCode retval;
 
-	retval = CORBA_TypeCode_allocate ();
+	retval = ORBit_TypeCode_allocate ();
 	if (!retval) {
 		CORBA_exception_set_system (
 				ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
@@ -845,7 +845,7 @@ CORBA_ORB_create_string_tc (CORBA_ORB                  orb,
 {
 	CORBA_TypeCode retval;
 
-	retval = CORBA_TypeCode_allocate ();
+	retval = ORBit_TypeCode_allocate ();
 	if (!retval) {
 		CORBA_exception_set_system (
 				ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
@@ -866,7 +866,7 @@ CORBA_ORB_create_wstring_tc (CORBA_ORB                  orb,
 {
 	CORBA_TypeCode retval;
 
-	retval = CORBA_TypeCode_allocate ();
+	retval = ORBit_TypeCode_allocate ();
 	if (!retval) {
 		CORBA_exception_set_system (
 				ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
@@ -888,7 +888,7 @@ CORBA_ORB_create_fixed_tc (CORBA_ORB                   orb,
 {
 	CORBA_TypeCode retval;
 
-	retval = CORBA_TypeCode_allocate ();
+	retval = ORBit_TypeCode_allocate ();
 	if (!retval) {
 		CORBA_exception_set_system (
 				ev, ex_CORBA_NO_MEMORY, CORBA_COMPLETED_NO);
@@ -911,7 +911,7 @@ CORBA_ORB_create_sequence_tc (CORBA_ORB                  orb,
 {
 	CORBA_TypeCode retval;
 
-	retval = CORBA_TypeCode_allocate ();
+	retval = ORBit_TypeCode_allocate ();
 	if (!retval)
 		goto tc_alloc_failed;
 
@@ -945,7 +945,7 @@ CORBA_ORB_create_recursive_sequence_tc (CORBA_ORB                  orb,
 {
 	CORBA_TypeCode retval;
 
-	retval=CORBA_TypeCode_allocate ();
+	retval=ORBit_TypeCode_allocate ();
 	if (retval)
 		goto tc_alloc_failed;
 
@@ -957,7 +957,7 @@ CORBA_ORB_create_recursive_sequence_tc (CORBA_ORB                  orb,
 	retval->sub_parts = 1;
 	retval->length    = bound;
 
-	retval->subtypes [0] = CORBA_TypeCode_allocate ();
+	retval->subtypes [0] = ORBit_TypeCode_allocate ();
 
 	retval->subtypes [0]->kind          = CORBA_tk_recursive;
 	retval->subtypes [0]->recurse_depth = offset;
@@ -982,7 +982,7 @@ CORBA_ORB_create_array_tc (CORBA_ORB                  orb,
 {
 	CORBA_TypeCode tc;
 
-	tc = CORBA_TypeCode_allocate ();
+	tc = ORBit_TypeCode_allocate ();
 	if (!tc)
 		goto tc_alloc_failed;
 
