@@ -2,22 +2,44 @@
 #define __ORBIT_DEBUG_H__
 
 typedef enum {
-	ORBIT_DEBUG_NONE     = 0,
-	ORBIT_DEBUG_TRACES   = 1 << 0,
-	ORBIT_DEBUG_TIMINGS  = 1 << 1,
-	ORBIT_DEBUG_TYPES    = 1 << 2,
-	ORBIT_DEBUG_MESSAGES = 1 << 3,
-	ORBIT_DEBUG_OBJECTS  = 1 << 4,
-	ORBIT_DEBUG_GIOP     = 1 << 4,
+	ORBIT_DEBUG_NONE          = 0,
+	ORBIT_DEBUG_TRACES        = 1 << 0,
+	ORBIT_DEBUG_INPROC_TRACES = 1 << 1,
+	ORBIT_DEBUG_TIMINGS       = 1 << 2,
+	ORBIT_DEBUG_TYPES         = 1 << 3,
+	ORBIT_DEBUG_MESSAGES      = 1 << 4,
+	ORBIT_DEBUG_ERRORS        = 1 << 5,
+	ORBIT_DEBUG_OBJECTS       = 1 << 6,
+	ORBIT_DEBUG_GIOP          = 1 << 7,
+	ORBIT_DEBUG_REFS          = 1 << 8
 } OrbitDebugFlags;
 
 #ifndef G_ENABLE_DEBUG
 
 /*static inline void dprintf (OrbitDebugFlags flags, const char *format, ...) { };*/
-#define dprintf(...)
+#ifdef G_HAVE_ISO_VARARGS
+#  define dprintf(...)
+#  define tprintf(...)
+#elif defined(G_HAVE_GNUC_VARARGS)
+#  define dprintf(args...)
+#  define tprintf(args...)
+#else
+/* This sucks for compatibility - fix your compiler */
+#define MESSAGES (OrbitDebugFlags)0
+#define TYPES    (OrbitDebugFlags)0
+#define OBJECTS  (OrbitDebugFlags)0
+#define GIOP     (OrbitDebugFlags)0
+#define ERRORS   (OrbitDebugFlags)0
+static inline void dprintf (OrbitDebugFlags flags, const char *format, ...)
+{
+}
+static inline void tprintf (const char *format, ...)
+{
+}
+#endif
+
 #define dump_arg(a,b)
 
-#define tprintf(...)
 #define tprintf_header(obj,md)
 #define tprintf_trace_value(a,b)
 #define tprintf_timestamp()
@@ -30,10 +52,17 @@ typedef enum {
 
 extern OrbitDebugFlags _orbit_debug_flags;
 
-#define dprintf(type, ...) G_STMT_START {		\
+#ifdef G_HAVE_ISO_VARARGS
+#  define dprintf(type, ...) G_STMT_START {		\
 	if (_orbit_debug_flags & ORBIT_DEBUG_##type)	\
 		fprintf (stderr, __VA_ARGS__);		\
-} G_STMT_END
+	} G_STMT_END
+#elif defined(G_HAVE_GNUC_VARARGS)
+#  define dprintf(type, args...) G_STMT_START {		\
+	if (_orbit_debug_flags & ORBIT_DEBUG_##type)	\
+		fprintf (stderr, args);			\
+	} G_STMT_END
+#endif
 
 static inline void
 dump_arg (const ORBit_IArg *a, CORBA_TypeCode tc)
@@ -56,27 +85,31 @@ void     ORBit_trace_end_method (void);
 void     ORBit_trace_profiles   (CORBA_Object obj);
 void     ORBit_trace_timestamp  (void);
 
-#define tprintf(...)  dprintf (TRACES, __VA_ARGS__)
+#ifdef G_HAVE_ISO_VARARGS
+#  define tprintf(...)  dprintf (TRACES, __VA_ARGS__)
+#elif defined(G_HAVE_GNUC_VARARGS)
+#  define tprintf(args...)  dprintf (TRACES, args)
+#endif
 
 #define tprintf_header(obj,md)		G_STMT_START {		\
 	if (_orbit_debug_flags & ORBIT_DEBUG_TRACES)		\
 		ORBit_trace_header (obj,md);			\
-} G_STMT_END
+	} G_STMT_END
 
 #define tprintf_trace_value(a,b)	G_STMT_START {		\
 	if (_orbit_debug_flags & ORBIT_DEBUG_TRACES)		\
 		ORBit_trace_value ((gconstpointer *)(a), (b));	\
-} G_STMT_END
+	} G_STMT_END
 
 #define tprintf_end_method() 		G_STMT_START {		\
 	if (_orbit_debug_flags & ORBIT_DEBUG_TRACES)		\
 		ORBit_trace_end_method ();			\
-} G_STMT_END
+	} G_STMT_END
 
 #define tprintf_timestamp()		G_STMT_START {		\
 	if (_orbit_debug_flags & ORBIT_DEBUG_TIMINGS)		\
 		ORBit_trace_timestamp ();			\
-} G_STMT_END
+	} G_STMT_END
 
 #endif /* G_ENABLE_DEBUG */
 
