@@ -25,6 +25,8 @@
 #include <string.h>
 #include <stdlib.h>
 
+#include "orbit-imodule.h"
+
 /* Singleton accessor for the test factory */
 test_TestFactory getFactoryInstance(CORBA_Environment *ev);
 
@@ -422,6 +424,27 @@ create_TestFactory (PortableServer_POA        poa,
 
 test_TestFactory_Servant servant;
 
+static void
+init_iinterfaces (ORBit_IInterfaces *interfaces)
+{
+	test_TestFactory__iinterface      = interfaces->_buffer [0];
+	test_DeadReferenceObj__iinterface = interfaces->_buffer [1];
+	test_TransientObj__iinterface     = interfaces->_buffer [2];
+	test_SequenceServer__iinterface   = interfaces->_buffer [3];
+	test_ArrayServer__iinterface      = interfaces->_buffer [4];
+	test_BasicServer__iinterface      = interfaces->_buffer [5];
+	test_StructServer__iinterface     = interfaces->_buffer [6];
+	test_BaseServer__iinterface       = interfaces->_buffer [7];
+	test_B1__iinterface               = interfaces->_buffer [8];
+	test_B2__iinterface               = interfaces->_buffer [9];
+	test_C1__iinterface               = interfaces->_buffer [10];
+	test_DerivedServer__iinterface    = interfaces->_buffer [11];
+	test_UnionServer__iinterface      = interfaces->_buffer [12];
+	test_AnyServer__iinterface        = interfaces->_buffer [13];
+	test_ContextServer__iinterface    = interfaces->_buffer [14];
+	test_PingPongServer__iinterface   = interfaces->_buffer [15];
+}
+
 #ifndef _IN_CLIENT_
   int
   main (int argc, char *argv [])
@@ -435,6 +458,9 @@ test_TestFactory_Servant servant;
 #ifndef _IN_CLIENT_
 	CORBA_Environment real_ev;
 	CORBA_Environment *ev = &real_ev;
+	ORBit_IInterfaces *interfaces = NULL;
+	gboolean           gen_imodule = FALSE;
+	int                i;
 
 /*	g_mem_set_vtable (glib_mem_profiler_table); */
 
@@ -448,6 +474,17 @@ test_TestFactory_Servant servant;
 
 	global_orb = CORBA_ORB_init (&argc, argv, "", ev);
 	g_assert (ev->_major == CORBA_NO_EXCEPTION);
+
+	for (i = 0; i < argc; i++)
+		if (!strcmp (argv [i], "--gen-imodule"))
+			gen_imodule = TRUE;
+
+	if (gen_imodule) {
+		interfaces = ORBit_iinterfaces_from_file ("everything.idl", NULL, NULL);
+		g_assert (interfaces != NULL);
+
+		init_iinterfaces (interfaces);
+        }
 #endif
 
 	global_poa = start_poa (global_orb, ev);
@@ -478,6 +515,9 @@ test_TestFactory_Servant servant;
 
 	g_warning ("released factory");
 
+	if (gen_imodule)
+		CORBA_free (interfaces);
+
 	CORBA_ORB_destroy (global_orb, ev);
 	g_assert (ev->_major == CORBA_NO_EXCEPTION);
 
